<script setup>

import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import { ref, onMounted, computed } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';
import NavLink from '@/Components/NavLink.vue';

const page = usePage();
console.log(page.props);
const products = computed(() => page.props.products.data || []);
const carMakes = computed(() => page.props.carMakes || []);
const carModels = computed(() => page.props.carModels || []);
const carBodyStyles = computed(() => page.props.carBodyStyles || []);
const loading = computed(() => page.props.loading || false);
const perPageOptions = [10, 20, 50]; // Adjust as needed
const perPage = ref(perPageOptions[0]);
const firstpage = ref(null);
const lastpage = ref(null);
const nextpage = ref(null);
const previouspage = ref(null);
const totalPages = ref(null);
const currentPage = ref(null);
const urlPerPage = ref(page.props.per_page);
const flashMessage = ref('');
const isMobile = ref(window.innerWidth <= 768);

if(perPage != urlPerPage) {
    perPage.value = urlPerPage.value;
}

const form = useForm({
    item_number: '',
});

const sortDirections = ref({});
const sortBy = (key) => {
  // If the key has not been sorted before, default to ascending
  if (!sortDirections.value[key]) {
    sortDirections.value[key] = 'asc';
  } else {
    // If it was ascending before, now make it descending, and vice versa
    sortDirections.value[key] = sortDirections.value[key] === 'asc' ? 'desc' : 'asc';
  }

  const direction = sortDirections.value[key];

  products.value.sort((a, b) => {
    if (a[key] < b[key]) {
      return direction === 'asc' ? -1 : 1;
    }
    if (a[key] > b[key]) {
      return direction === 'asc' ? 1 : -1;
    }
    return 0;
  });
};

const handleResize = () => {
    isMobile.value = window.innerWidth <= 768; // Adjust the threshold as needed
}

const sortedProducts = computed(() => products.value);

const changePerPage = () => {
    window.location.href = getLinkUrl();
};

const getLinkUrl = () => {
  // Build the URL with the selected per page value
  return `/admin/products?per_page=${perPage.value}`;
};

const editProduct = (product) => {
  // Implement your edit logic here
  console.log('Edit product:', product);
  window.location.href = `/admin/product/edit/${product.id}`;
};

const deleteProduct = (product) => {
  const productID = product.id

  if (confirm('Are you sure you want to delete this product?')) {
    form.post(route('admin.products.delete',{id: productID}), {
        onSuccess: () => {
            // Update your success message or perform other actions here
            flashMessage.value = "Product deleted successfully!";
        },
        onError: (error) => {
            // Handle error case here, if needed
            console.error(error);
        }
    });
  }
};

onMounted(() => {
    const query = usePage().props;
    firstpage.value = query.products.first_page_url;
    lastpage.value = query.products.last_page_url;
    nextpage.value = query.products.next_page_url;
    previouspage.value = query.products.prev_page_url;
    totalPages.value = query.products.last_page;
    currentPage.value = query.products.current_page;
    window.addEventListener('resize', handleResize);
    handleResize();
});
</script>

<template>
    <Head title="All Products" />

    <AdminAuthenticatedLayout>
        <template #header>
            <div class="flex">
                <h2 class="font-semibold text-xl text-gray-800 leading-tight">Products
                    <NavLink :href="route('admin.products.add')" :active="route().current('admin.products.add')">
                        + Add Product
                    </NavLink>
                </h2>
            </div>
        </template>

        <div class="py-12">
            <div v-if="flashMessage" class="max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                <div class="form-row mb-6">
                    <div class="col-md-6">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
                <label for="perPageSelect">Per Page </label>
                <select id="perPageSelect" class="sm:mx-3 sm:mb-6" v-model="perPage" @change="changePerPage">
                    <option v-for="option in perPageOptions" :key="option" :value="option">
                        {{ option }}
                    </option>
                </select>
                <nav class="flex" style="width:200px;display: inline-block;float:right;">
                    <ul class="pagination" style="float:right;">
                        <li class="page-item">
                            <a class="page-link" :href="firstpage" v-if="firstpage && currentPage != totalPages"><span aria-hidden="true">&laquo;</span></a>
                        </li>
                        <li class="page-item">
                            <a class="page-link" :href="previouspage + '&per_page='+perPage" v-if="previouspage">Prev</a>
                        </li>
                        <li class="page-item" style="width: 80px;text-align: center;">
                            <a class="page-link"> {{ currentPage }} of {{ totalPages }}</a>
                        </li>
                        <li class="page-item">
                            <a class="page-link" :href="nextpage + '&per_page='+perPage" v-if="nextpage">Next</a>
                        </li>
                        <li class="page-item">
                            <a class="page-link" :href="lastpage" v-if="lastpage && currentPage != totalPages"><span aria-hidden="true">&raquo;</span></a>
                        </li>
                    </ul>
                </nav>
                <div v-if="loading">Loading...</div>
                <table v-else-if="products && products.length" class="table table-striped">
                    <thead>
                        <tr>
                        <th @click="sortBy('item_number')">Item Number</th>
                        <th @click="sortBy('price')">Price</th>
                        <th v-if="!isMobile" @click="sortBy('year')">Year</th>
                        <th v-if="!isMobile && carMakes.length > 0" @click="sortBy('make')">Make</th>
                        <th v-if="!isMobile && carModels.length > 0" @click="sortBy('model')">Model</th>
                        <th v-if="!isMobile && carBodyStyles.length > 0" @click="sortBy('bodystyle')">Body Style</th>
                        <th @click="sortBy('quantity')">Stock</th>
                        <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr v-for="product in sortedProducts" :key="product.id">
                        <td>{{ product.item_number }}</td>
                        <td>{{ product.price }}</td>
                        <td v-if="!isMobile" >{{ product.year }}</td>
                        <td v-if="!isMobile && carMakes.length > 0" >{{ carMakes.find(item => item.id == product.make).name }}</td>
                        <td v-if="!isMobile && carModels.length > 0" >{{ carModels.find(item => item.id == product.model).name }}</td>
                        <td v-if="!isMobile && carBodyStyles.length > 0" >{{ carBodyStyles.find(item => item.id == product.bodystyle).name }}</td>
                        <td :class="product.stock == 1 ? 'text-success' : 'text-danger'">{{ product.stock == 1 ? "In Stock" : "Please Call" }}</td>
                        <td>
                            <button class="px-3" @click="editProduct(product)"><i class="fa fa-pen text-green-600"></i></button>
                            <button class="mx-3" @click="deleteProduct(product)"><i class="fa fa-trash text-red-600"></i></button>
                        </td>
                        </tr>
                    </tbody>
                </table>
                <p v-else>No products found.</p>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
